@@ -3,7 +3,7 @@ from itertools import ifilter
 
 
 __all__ = ['identity', 'constantly', 'caller',
-           'partial', 'compose', 'complement',
+           'partial', 'curry', 'compose', 'complement',
            'juxt', 'ijuxt',
            'iffy']
 
@@ -22,6 +22,15 @@ def caller(*a, **kw):
 def partial(func, *args, **kwargs):
     return lambda *a, **kw: func(*(args + a), **dict(kwargs, **kw))
 
+def curry(func, n=None):
+    if n is None:
+        n = func.__code__.co_argcount
+
+    if n <= 1:
+        return func
+    else:
+        return lambda x: curry(lambda *y: func(x, *y), n - 1)
+
 def compose(*fs):
     pair = lambda f, g: lambda *a, **kw: f(g(*a, **kw))
     return reduce(pair, fs, identity)
@@ -35,5 +44,10 @@ def juxt(*fs):
 def ijuxt(*fs):
     return lambda *a, **kw: (f(*a, **kw) for f in fs)
 
-def iffy(pred, action, default=identity):
-    return lambda v: action(v) if pred(v) else default(v)
+def iffy(pred, action=None, default=identity):
+    if action is None:
+        return iffy(bool, pred)
+    else:
+        return lambda v: action(v)  if pred(v) else           \
+                         default(v) if callable(default) else \
+                         default
